<?php
/*
 *
 *  XHP - eXpandable Home Page [xhp.targetit.ro]
 *  Copyright (C) 2003-2005
 *  Laurentiu "Lars" Matei <laurentiu.matei@targetit.ro>
 *
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

require_once ("inc/authentication.inc.php");
require_once("inc/gettext/streams.php");
require_once("inc/gettext/gettext.php");

class xhp_module
{
	var $box_id;
	var $page_id;
	var $main_module = 0;
	var $access_level = XHP_ACCESS_NONE;
	var $module_name;
	var $valid_actions = array();
	var $clean_get = array();
	var $l10n;
	
	/**
	 * Constructor
	 * It sets module data and initializes gettext
	 *
	 * @param string $module_name
	 * @param int $box_id
	 * @param int $page_id
	 * @param int $access_level
	 * @return xhp_module
	 */
	function xhp_module($module_name, $box_id, $page_id, $access_level)
	{
		$this->module_name = $module_name;
		$this->box_id = $box_id;
		$this->page_id = $page_id;
		$this->access_level = $access_level;
		
		require_once ("config.php");
		global $db;
		$language = "english";
		$language = $db->get_var ("SELECT value FROM ".XHP_TBL_PREFIX."config WHERE variable='LANGUAGE' LIMIT 1");
		$this->php_gettext_init($language);
		
		$this->process_input();
	}
	
	function php_gettext_init($language)
	{
		$language_file = "";
		if (file_exists("languages/lang-".$language."-".$this->module_name.".mo"))
		{
			$language_file = "languages/lang-".$language."-".$this->module_name.".mo";
		}
		elseif (file_exists("languages/lang-english-".$this->module_name.".mo"))
		{
			$language_file = "languages/lang-english-".$this->module_name.".mo";
		}
		elseif (file_exists("languages/lang-".$language.".mo"))
		{
			$language_file = "languages/lang-".$language.".mo";
		}
		else
		{
			$language_file = "languages/lang-english.mo";
		}
		$input = new FileReader($language_file);
		$this->l10n = new gettext_reader($input);
	}

	// create standard wrapers, so xgettext could work
	function T_($text) 
	{
	  	return $this->l10n->translate($text);
	}

	function T_ngettext($single, $plural, $number) 
	{
		return $this->l10n->ngettext($single, $plural, $number);
	}

	
	function register_valid_actions()
	{
	}

	
	function process_input()
	{
		// sanitize input variables
		$this->register_valid_actions();
		if (isset($_GET['action']))
			if (in_array($_GET['action'],$this->valid_actions))
				$this->clean_get['action'] = $_GET['action'];

		// $_GET['errcode'] is displayed if non zero, so it should not have html tags
		if (isset($_GET['errcode']))
		{
			$this->clean_get['errcode'] = strip_tags($_GET['errcode']);
		}
	}
	
	function test_error()
	{
		// Test error code if coming from action function
		if (isset($this->clean_get['errcode']))
			if ($this->clean_get['errcode']!="0")
			{
				// An error occured in the action function
				// User is notified here
				echo "<p style=\"color:red;\">".$this->clean_get['errcode']."</p>\n";
			}
	}
	
	
	/**
	 * Method to draw a form tag for use in XHP (usually in edit window)
	 *
	 * @param string $module The module to be called
	 * @param string $action The method in the module class to be called
	 * @param string $redirect_to The redirect string appended to index.php?
	 * @param array $parameters Array of parameters for the method
	 * @param boolean $closewindow Close window after form submit
	 */
	function draw_form_tag($module,$action,$redirect_to,$parameters=array(),$closewindow=false)
	{

		$var_redirect_to = $redirect_to;
        if ($var_redirect_to == null)
        {
        	// get current parameters
        	$var_redirect_to = $_SERVER['QUERY_STRING'];
        }


        $parameters_string = "";
        foreach ($parameters as $parameter => $value)
        {
        	$parameters_string .= "&amp;".$parameter."=".$value;
        }

		echo "<form action=\"action.php?module=".$module."&amp;action=".$action."&amp;box_id=".$this->box_id."&amp;page_id=".$this->page_id."&amp;basename=".basename($_SERVER['PHP_SELF'])."&amp;closewindow=".$closewindow."&amp;from_page=".urlencode(urlencode($var_redirect_to)).$parameters_string."\" method=\"post\" enctype=\"multipart/form-data\">\n";
	}

	/**
	 * Method to draw an action link
	 *
	 * @param string $text  The text displayed on the link
	 * @param string $module The module to be called
	 * @param string $action The method in the module class to be called
	 * @param string $redirect_to The redirect string appended to index.php?
	 * @param array $parameters Array of parameters for the method
	 * @param boolean $closewindow Close window after executing action
	 */
	function draw_action_link($text,$module,$action,$redirect_to,$parameters=array(),$closewindow=false)
	{
		$var_redirect_to = $redirect_to;
        if ($var_redirect_to == null)
        {
        	// get current parameters
        	$var_redirect_to = $_SERVER['QUERY_STRING'];
        }

        $parameters_string = "";
        foreach ($parameters as $parameter => $value)
        {
        	$parameters_string .= "&amp;".$parameter."=".$value;
        }

		echo "<a href=\"action.php?module=".$module."&amp;action=".$action."&amp;box_id=".$this->box_id."&amp;page_id=".$this->page_id."&amp;basename=".basename($_SERVER['PHP_SELF'])."&amp;closewindow=".$closewindow."&amp;from_page=".urlencode(urlencode($var_redirect_to)).$parameters_string."\">".$text."</a>";
	}


	/**
	 * Method to draw an edit link that opens an edit window
	 *
	 * @param string $text  The text displayed on the link
	 * @param string $module The module to be called
	 * @param string $action The method in the module class to be called
	 * @param string $redirect_to The redirect string appended to index.php?
	 * @param array $parameters Array of parameters for the method
	 */
	function draw_edit_link($text,$module,$action,$redirect_to,$parameters=array())
	{
		$var_redirect_to = $redirect_to;
        if ($var_redirect_to == null)
        {
        	// get current parameters
        	$var_redirect_to = $_SERVER['QUERY_STRING'];
        }

        $parameters_string = "";
        foreach ($parameters as $parameter => $value)
        {
        	$parameters_string .= "&amp;".$parameter."=".$value;
        }

		$url = "editwindow.php?module=".$module."&amp;action=".$action."&amp;box_id=".$this->box_id."&amp;page=".$this->page_id."&amp;from_page=".urlencode(urlencode($var_redirect_to)).$parameters_string;
		echo "<a href=\"".$url."\" target=\"editdialog\" onClick=\"window.open(this.href,'editdialog','toolbar=no,menubar=no,personalbar=no,width=600,height=500,scrollbars=yes,resizable=yes,modal=yes,dependable=yes'); return false;\">".$text."</a>";
	}


    function global_execute()
    {
    	// this function is executed on every page
    	// it has been built for the statistics module but maybe other uses can be found
    }

	function change_headers()
	{
	}

	/**
	 * Set a value in the headers array
	 * Example:
	 *   $this->set_header("title","<title>".XHP_C_PAGE_TITLE."</title>\n");
	 *
	 * @param string $key
	 * @param string $value
	 * 
	 */
	function set_header($key,$value)
	{
		global $headers;
		$update = true;
		// only the main module in a page can overwrite a header
		if ((isset($headers[$key]))&&($this->main_module==0))
			$update = false;
		if ($key == "live_bookmark")
		{
			// Live bookmarks are added from all module instances
			// They don't override each other
			$headers[] = $value;
			return;
		}
		
		else if ($update)
			$headers[$key] = $value;
	}

	/**
	 * Override this method to clean up when a module instance is deleted
	 *
	 */
	function delete_instance()
	{
	}
	
	/**
	 * Override this method to clean up when a module is deleted
	 *
	 */
	function delete_module()
	{
	}

}
?>